import requests

def main():
    url = "https://server-fuie.onrender.com/message?prompt="

    def generate(prompt):
        response = requests.get(url + prompt)
        return response.text

    while True:
        prompt = input("User: ")
        if prompt == "exit":
            break
        message = generate(prompt)
        print("Chikku: " + message)



# setup.py
from setuptools import setup, find_packages

setup(
    name='chikku',
    version='0.1',
    packages=find_packages(),
    install_requires=[
        'requests',
    ],
    entry_points={
        'console_scripts': [
            'chikku = chikku.chikku:main',
        ],
    },
)
